@@ -22,7 +22,7 @@ def list_diff(a, b):
 
 
 def sh(cmd):
-    subprocess.Popen(cmd.split()).wait()
+    return subprocess.Popen(cmd.split()).wait()
 
 
 def sh_in(_dir, cmd):
